EXPORTS
	?Gain@CMdaAudioInputStream@@QBEHXZ @ 1 NONAME ; public: int __thiscall CMdaAudioInputStream::Gain(void)const 
	?GetBalanceL@CMdaAudioInputStream@@QBEHXZ @ 2 NONAME ; public: int __thiscall CMdaAudioInputStream::GetBalanceL(void)const 
	?GetBytes@CMdaAudioInputStream@@QAEHXZ @ 3 NONAME ; public: int __thiscall CMdaAudioInputStream::GetBytes(void)
	?MaxGain@CMdaAudioInputStream@@QBEHXZ @ 4 NONAME ; public: int __thiscall CMdaAudioInputStream::MaxGain(void)const 
	?NewL@CMdaAudioInputStream@@SAPAV1@AAVMMdaAudioInputStreamCallback@@@Z @ 5 NONAME ; public: static class CMdaAudioInputStream * __cdecl CMdaAudioInputStream::NewL(class MMdaAudioInputStreamCallback &)
	?NewL@CMdaAudioInputStream@@SAPAV1@AAVMMdaAudioInputStreamCallback@@HH@Z @ 6  NONAME ; class CMdaAudioInputStream * CMdaAudioInputStream::NewL(class MMdaAudioInputStreamCallback &, int, int)
	?Open@CMdaAudioInputStream@@QAEXPAVTMdaPackage@@@Z @ 7 NONAME ; public: void __thiscall CMdaAudioInputStream::Open(class TMdaPackage *)
	?Position@CMdaAudioInputStream@@QAEABVTTimeIntervalMicroSeconds@@XZ @ 8 NONAME ; public: class TTimeIntervalMicroSeconds const & __thiscall CMdaAudioInputStream::Position(void)
	?ReadL@CMdaAudioInputStream@@QAEXAAVTDes8@@@Z @ 9 NONAME ; public: void __thiscall CMdaAudioInputStream::ReadL(class TDes8 &)
	?SetAudioPropertiesL@CMdaAudioInputStream@@QAEXHH@Z @ 10 NONAME ; public: void __thiscall CMdaAudioInputStream::SetAudioPropertiesL(int,int)
	?SetBalanceL@CMdaAudioInputStream@@QAEXH@Z @ 11 NONAME ; public: void __thiscall CMdaAudioInputStream::SetBalanceL(int)
	?SetGain@CMdaAudioInputStream@@QAEXH@Z @ 12 NONAME ; public: void __thiscall CMdaAudioInputStream::SetGain(int)
	?SetPriority@CMdaAudioInputStream@@QAEXHH@Z @ 13 NONAME ; void CMdaAudioInputStream::SetPriority(int, int)
	?Stop@CMdaAudioInputStream@@QAEXXZ @ 14 NONAME ; public: void __thiscall CMdaAudioInputStream::Stop(void)
	?DataType@CMdaAudioInputStream@@QBE?AVTFourCC@@XZ @ 15 NONAME ; public: class TFourCC  __thiscall CMdaAudioInputStream::DataType(void)const 
	?SetDataTypeL@CMdaAudioInputStream@@QAEXVTFourCC@@@Z @ 16 NONAME ; public: void __thiscall CMdaAudioInputStream::SetDataTypeL(class TFourCC)
	?BitRateL@CMdaAudioInputStream@@QBEHXZ @ 17 NONAME ; int CMdaAudioInputStream::BitRateL(void) const
	?GetSupportedBitRatesL@CMdaAudioInputStream@@QAEXAAV?$RArray@H@@@Z @ 18 NONAME ; void CMdaAudioInputStream::GetSupportedBitRatesL(class RArray<int> &)
	?SetBitRateL@CMdaAudioInputStream@@QAEXH@Z @ 19 NONAME ; void CMdaAudioInputStream::SetBitRateL(int)
	?CustomInterface@CMdaAudioInputStream@@QAEPAXVTUid@@@Z @ 20 NONAME ; void * CMdaAudioInputStream::CustomInterface(class TUid)
	?SetSingleBufferMode@CMdaAudioInputStream@@QAEXH@Z @ 21 NONAME ; void CMdaAudioInputStream::SetSingleBufferMode(int)
	?RequestStop@CMdaAudioInputStream@@QAEXXZ @ 22 NONAME ; void CMdaAudioInputStream::RequestStop(void)

